s = zpk('s');
z = zpk('z');

P = 1/(s+3)^3;       % Some plant

K = 20;
Ti = 1;
C = K*(1+1/(s*Ti));  % Some PI controller

h = 0.5/bandwidth(feedback(P*C,1));

Pd = balreal(c2d(P,h) * z/(z-1));         % Plant with input integrator
[Ap,Bp,Cp] = ssdata(Pd);
Rd = blkdiag(Bp*Bp',0);  % Noise on state and output
Qc = blkdiag(Cp'*Cp,0);  % Cost on state and output

Cd = -balreal(ss((z-1)/z * c2d(C,h,'foh'),'min'));  % Controller with output differentiator

Samp = 1;
Act = 1;

N = jtInit;
N = jtAddDiscSys(N,1,Pd,4,Rd,Qc);
N = jtAddDiscSys(N,2,Samp,1);
N = jtAddDiscSys(N,3,Cd,2);
N = jtAddDiscSys(N,4,Act,3);
N = jtCalcDynamics(N);

N = jtBeginPeriodicAnalysis(N);
N = jtExecSys(N,2);  % Sampler
N = jtExecSys(N,1);  % Evolve plant
N = jtPassTime(N,h); % Pass time (not really needed here)
N = jtExecSys(N,3);  % Controller
N = jtExecSys(N,4);  % Actuator
N = jtEndPeriodicAnalysis(N);

N.P = N.Pperiodic; % Set initial variance to periodic variance

